==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppDeploymentSlotArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.WebAppDeploymentSlotArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * User credentials used for publishing activity.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppDeploymentSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/deployments/{id}
 * ```
 * @property active True if deployment is currently active, false if completed and null if not started.
 * @property author Who authored the deployment.
 * @property authorEmail Author email.
 * @property deployer Who performed the deployment.
 * @property details Details on deployment.
 * @property endTime End time.
 * @property id ID of an existing deployment.
 * @property kind Kind of resource.
 * @property message Details about deployment status.
 * @property name Name of the app.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property slot Name of the deployment slot. If a slot is not specified, the API creates a deployment for the production slot.
 * @property startTime Start time.
 * @property status Deployment status.
 */
public data class WebAppDeploymentSlotArgs(
    public val active: Output<Boolean>? = null,
    public val author: Output<String>? = null,
    public val authorEmail: Output<String>? = null,
    public val deployer: Output<String>? = null,
    public val details: Output<String>? = null,
    public val endTime: Output<String>? = null,
    public val id: Output<String>? = null,
    public val kind: Output<String>? = null,
    public val message: Output<String>? = null,
    public val name: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val slot: Output<String>? = null,
    public val startTime: Output<String>? = null,
    public val status: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.WebAppDeploymentSlotArgs> {
    override fun toJava(): com.pulumi.azurenative.web.WebAppDeploymentSlotArgs =
        com.pulumi.azurenative.web.WebAppDeploymentSlotArgs.builder()
            .active(active?.applyValue({ args0 -> args0 }))
            .author(author?.applyValue({ args0 -> args0 }))
            .authorEmail(authorEmail?.applyValue({ args0 -> args0 }))
            .deployer(deployer?.applyValue({ args0 -> args0 }))
            .details(details?.applyValue({ args0 -> args0 }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .kind(kind?.applyValue({ args0 -> args0 }))
            .message(message?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .slot(slot?.applyValue({ args0 -> args0 }))
            .startTime(startTime?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAppDeploymentSlotArgs].
 */
@PulumiTagMarker
public class WebAppDeploymentSlotArgsBuilder internal constructor() {
    private var active: Output<Boolean>? = null

    private var author: Output<String>? = null

    private var authorEmail: Output<String>? = null

    private var deployer: Output<String>? = null

    private var details: Output<String>? = null

    private var endTime: Output<String>? = null

    private var id: Output<String>? = null

    private var kind: Output<String>? = null

    private var message: Output<String>? = null

    private var name: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var slot: Output<String>? = null

    private var startTime: Output<String>? = null

    private var status: Output<Int>? = null

    /**
     * @param value True if deployment is currently active, false if completed and null if not started.
     */
    @JvmName("vcnovkcbnexbolsw")
    public suspend fun active(`value`: Output<Boolean>) {
        this.active = value
    }

    /**
     * @param value Who authored the deployment.
     */
    @JvmName("cowndnbmoehqkqbx")
    public suspend fun author(`value`: Output<String>) {
        this.author = value
    }

    /**
     * @param value Author email.
     */
    @JvmName("pwrfnojixefkweoo")
    public suspend fun authorEmail(`value`: Output<String>) {
        this.authorEmail = value
    }

    /**
     * @param value Who performed the deployment.
     */
    @JvmName("hqroinpkcrkcxnnr")
    public suspend fun deployer(`value`: Output<String>) {
        this.deployer = value
    }

    /**
     * @param value Details on deployment.
     */
    @JvmName("pkdknviqghgesdns")
    public suspend fun details(`value`: Output<String>) {
        this.details = value
    }

    /**
     * @param value End time.
     */
    @JvmName("ydccagmtdebmplac")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value ID of an existing deployment.
     */
    @JvmName("hvyvvnamqslqlaxv")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("yilqonuvaqghwhvm")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Details about deployment status.
     */
    @JvmName("dbburxaaydckeody")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("oypfhwaotqhxrfad")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("cclaratexqaebptq")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API creates a deployment for the production slot.
     */
    @JvmName("tlyjukaoybleesyp")
    public suspend fun slot(`value`: Output<String>) {
        this.slot = value
    }

    /**
     * @param value Start time.
     */
    @JvmName("glisjxtgykoqmyqu")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Deployment status.
     */
    @JvmName("phxqnahfnhkrkgnm")
    public suspend fun status(`value`: Output<Int>) {
        this.status = value
    }

    /**
     * @param value True if deployment is currently active, false if completed and null if not started.
     */
    @JvmName("xsribqijnqbxqsrt")
    public suspend fun active(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.active = mapped
    }

    /**
     * @param value Who authored the deployment.
     */
    @JvmName("wfgeblwxyvqyessw")
    public suspend fun author(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.author = mapped
    }

    /**
     * @param value Author email.
     */
    @JvmName("gtcirbyhncqiopam")
    public suspend fun authorEmail(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorEmail = mapped
    }

    /**
     * @param value Who performed the deployment.
     */
    @JvmName("djivxlbitamcukef")
    public suspend fun deployer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deployer = mapped
    }

    /**
     * @param value Details on deployment.
     */
    @JvmName("expedjxvifwthdbq")
    public suspend fun details(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.details = mapped
    }

    /**
     * @param value End time.
     */
    @JvmName("iwgslvpwnmiuspjt")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value ID of an existing deployment.
     */
    @JvmName("bpwmsgjbgsaebxsy")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("iofsrregyewgvxtu")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Details about deployment status.
     */
    @JvmName("qsmfaxbnppkcibnh")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("lnapjbgapmdjlidn")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("xtmrknqmdroodlup")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API creates a deployment for the production slot.
     */
    @JvmName("hhrysycgrfmxdfku")
    public suspend fun slot(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slot = mapped
    }

    /**
     * @param value Start time.
     */
    @JvmName("lhrobooigehysnnn")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    /**
     * @param value Deployment status.
     */
    @JvmName("ofxvhixkbpfptmmk")
    public suspend fun status(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): WebAppDeploymentSlotArgs = WebAppDeploymentSlotArgs(
        active = active,
        author = author,
        authorEmail = authorEmail,
        deployer = deployer,
        details = details,
        endTime = endTime,
        id = id,
        kind = kind,
        message = message,
        name = name,
        resourceGroupName = resourceGroupName,
        slot = slot,
        startTime = startTime,
        status = status,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppDeploymentSlotArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.WebAppDeploymentSlotArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * User credentials used for publishing activity.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppDeploymentSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/deployments/{id}
 * ```
 * @property active True if deployment is currently active, false if completed and null if not started.
 * @property author Who authored the deployment.
 * @property authorEmail Author email.
 * @property deployer Who performed the deployment.
 * @property details Details on deployment.
 * @property endTime End time.
 * @property id ID of an existing deployment.
 * @property kind Kind of resource.
 * @property message Details about deployment status.
 * @property name Name of the app.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property slot Name of the deployment slot. If a slot is not specified, the API creates a deployment for the production slot.
 * @property startTime Start time.
 * @property status Deployment status.
 */
public data class WebAppDeploymentSlotArgs(
    public val active: Output<Boolean>? = null,
    public val author: Output<String>? = null,
    public val authorEmail: Output<String>? = null,
    public val deployer: Output<String>? = null,
    public val details: Output<String>? = null,
    public val endTime: Output<String>? = null,
    public val id: Output<String>? = null,
    public val kind: Output<String>? = null,
    public val message: Output<String>? = null,
    public val name: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val slot: Output<String>? = null,
    public val startTime: Output<String>? = null,
    public val status: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.WebAppDeploymentSlotArgs> {
    override fun toJava(): com.pulumi.azurenative.web.WebAppDeploymentSlotArgs =
        com.pulumi.azurenative.web.WebAppDeploymentSlotArgs.builder()
            .active(active?.applyValue({ args0 -> args0 }))
            .author(author?.applyValue({ args0 -> args0 }))
            .authorEmail(authorEmail?.applyValue({ args0 -> args0 }))
            .deployer(deployer?.applyValue({ args0 -> args0 }))
            .details(details?.applyValue({ args0 -> args0 }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .kind(kind?.applyValue({ args0 -> args0 }))
            .message(message?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .slot(slot?.applyValue({ args0 -> args0 }))
            .startTime(startTime?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAppDeploymentSlotArgs].
 */
@PulumiTagMarker
public class WebAppDeploymentSlotArgsBuilder internal constructor() {
    private var active: Output<Boolean>? = null

    private var author: Output<String>? = null

    private var authorEmail: Output<String>? = null

    private var deployer: Output<String>? = null

    private var details: Output<String>? = null

    private var endTime: Output<String>? = null

    private var id: Output<String>? = null

    private var kind: Output<String>? = null

    private var message: Output<String>? = null

    private var name: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var slot: Output<String>? = null

    private var startTime: Output<String>? = null

    private var status: Output<Int>? = null

    /**
     * @param value True if deployment is currently active, false if completed and null if not started.
     */
    @JvmName("ovgajvktwmscijny")
    public suspend fun active(`value`: Output<Boolean>) {
        this.active = value
    }

    /**
     * @param value Who authored the deployment.
     */
    @JvmName("jeiscqqcgthnltob")
    public suspend fun author(`value`: Output<String>) {
        this.author = value
    }

    /**
     * @param value Author email.
     */
    @JvmName("wihfdnxlbwfqrovu")
    public suspend fun authorEmail(`value`: Output<String>) {
        this.authorEmail = value
    }

    /**
     * @param value Who performed the deployment.
     */
    @JvmName("aaissbyhrmyxewfa")
    public suspend fun deployer(`value`: Output<String>) {
        this.deployer = value
    }

    /**
     * @param value Details on deployment.
     */
    @JvmName("dpwbmnqiqxhitffg")
    public suspend fun details(`value`: Output<String>) {
        this.details = value
    }

    /**
     * @param value End time.
     */
    @JvmName("iiexkagkaijfthse")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value ID of an existing deployment.
     */
    @JvmName("tpdsatdxdfkaamat")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("llauskemtqfwqjcu")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Details about deployment status.
     */
    @JvmName("xotvtlvuurjenjio")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("iqucakrcuhsorggs")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("vycugcmpafkwhnec")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API creates a deployment for the production slot.
     */
    @JvmName("arjcritafkedlpik")
    public suspend fun slot(`value`: Output<String>) {
        this.slot = value
    }

    /**
     * @param value Start time.
     */
    @JvmName("eafwsgrnhgyircvq")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Deployment status.
     */
    @JvmName("kqolmibuwghwwddb")
    public suspend fun status(`value`: Output<Int>) {
        this.status = value
    }

    /**
     * @param value True if deployment is currently active, false if completed and null if not started.
     */
    @JvmName("rqnukyaebvlkuask")
    public suspend fun active(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.active = mapped
    }

    /**
     * @param value Who authored the deployment.
     */
    @JvmName("hxqraxxqbqpfewxq")
    public suspend fun author(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.author = mapped
    }

    /**
     * @param value Author email.
     */
    @JvmName("frsggijaxprmotdf")
    public suspend fun authorEmail(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorEmail = mapped
    }

    /**
     * @param value Who performed the deployment.
     */
    @JvmName("pwdxmsghcnaknomj")
    public suspend fun deployer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deployer = mapped
    }

    /**
     * @param value Details on deployment.
     */
    @JvmName("rxkeugqulahitmcg")
    public suspend fun details(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.details = mapped
    }

    /**
     * @param value End time.
     */
    @JvmName("qfcxklrbvenffdxx")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value ID of an existing deployment.
     */
    @JvmName("kfiswimlttlqcgmt")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("sildnpiapudujdmh")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Details about deployment status.
     */
    @JvmName("naetiprttkcgcttd")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("hcxidvbxdrohddoq")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("rvhnbymqpgcofajc")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API creates a deployment for the production slot.
     */
    @JvmName("eandtgkpcwxfsoxb")
    public suspend fun slot(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slot = mapped
    }

    /**
     * @param value Start time.
     */
    @JvmName("vhlafdrohshrkiak")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    /**
     * @param value Deployment status.
     */
    @JvmName("nvjxiflemqtftwmb")
    public suspend fun status(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): WebAppDeploymentSlotArgs = WebAppDeploymentSlotArgs(
        active = active,
        author = author,
        authorEmail = authorEmail,
        deployer = deployer,
        details = details,
        endTime = endTime,
        id = id,
        kind = kind,
        message = message,
        name = name,
        resourceGroupName = resourceGroupName,
        slot = slot,
        startTime = startTime,
        status = status,
    )
}
